Zinnia Drupal documentation
===========================

Zinnia Drupal is a utility application for importing Drupal blog into Django
Blog Zinnia.


Support
-------

In case of problems with the application, please do not hesitate to contact the
author at **zinnia.drupal (at) majic.rs**. The application itself is hosted on
Github:

* https://github.com/azaghal/zinnia-drupal

Contents:

.. toctree::
   :maxdepth: 2

   about
   installation
   usage
   releasenotes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

